Skip to content

History

Usage

usage: galaxy history [-h] [-l] [-n HISTORY_NAME] [--history-id HISTORY_ID] [-i] [--recent]

UseGalaxy history utility.

options:
  -h, --help            show this help message and exit
  -l, --list            List user histories (default: True)
  -n, --history-name HISTORY_NAME
                        History name to filter on (default: None)
  --history-id, --check-history-id HISTORY_ID
                        History id to filter on (default: None)
  -i, --ignore-case     Search for histories by ignoring case (default: False)
  --recent              Display most recent history (not deleted) (default: False)

List histories

By default, its lists histories

galaxy history
or using the --list argument:
galaxy history --list

Search for an history by name

galaxy history --history-name Unn
will return all the histories that matches Unn

┏━━━━━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━━━━━━━━┓
┃ id               ┃ name            ┃ last modified       ┃
┡━━━━━━━━━━━━━━━━━━╇━━━━━━━━━━━━━━━━━╇━━━━━━━━━━━━━━━━━━━━━┩
│ dac8a4fd6ad7573f │ Unnamed history │ 2026-01-06 19:58:19 │
│ b25fbdc82ddd9710 │ Unnamed history │ 2026-01-06 19:18:55 │
└──────────────────┴─────────────────┴─────────────────────┘

Search case-insensitively

And you can search case-insensitively

galaxy history --history-name unn -i
will return all the histories that matches unn ignoring case

┏━━━━━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━━━━━━━━┓
┃ id               ┃ name            ┃ last modified       ┃
┡━━━━━━━━━━━━━━━━━━╇━━━━━━━━━━━━━━━━━╇━━━━━━━━━━━━━━━━━━━━━┩
│ dac8a4fd6ad7573f │ Unnamed history │ 2026-01-06 19:58:19 │
│ b25fbdc82ddd9710 │ Unnamed history │ 2026-01-06 19:18:55 │
└──────────────────┴─────────────────┴─────────────────────┘

Check existence

Check that an history exists

galaxy history --check <id>
or
galaxy history --history-id <id>

When the history exists this will return:

galaxy history --check b25fbdc82ddd9710

History with id b25fbdc82ddd9710 exists

and when it does not:

galaxy history --check A

History with id A does not exists

Recent history

Show the most recent used (not deleted) history

galaxy history --recent

┏━━━━━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━━━━━━━━┓
┃ id               ┃ name            ┃ last modified       ┃
┡━━━━━━━━━━━━━━━━━━╇━━━━━━━━━━━━━━━━━╇━━━━━━━━━━━━━━━━━━━━━┩
│ dac8a4fd6ad7573f │ Unnamed history │ 2026-01-06 19:58:19 │
└──────────────────┴─────────────────┴─────────────────────┘